//
//  SNGCardCreditDetailVC.swift
//  Nextgen Dev
//
//  Created by annguyen on 12/23/20.
//  Copyright © 2020 Chinh.nd. All rights reserved.
//

import Foundation
import UIKit

class SNGCardLevelDetailVC: SNGBaseViewController{
    @IBOutlet weak var header: SNGHead!
    @IBOutlet weak var colView: UICollectionView!
    @IBOutlet weak var stackView: UIStackView!
    @IBOutlet weak var btnEdit: SNGButton!
    @IBOutlet weak var btnConfirm: SNGButton!
    @IBOutlet weak var colViewConstrainBottom: NSLayoutConstraint!
    
    private let viewModelSoftOTP = SNGSoftOTPVM()
    
    var data: [SNGComboboxModel] = []
    var cardItem: SNGCardModel?
    var newAtmLimit: String?
    var newOnlineLimit: String?
    var endDate: String = ""
    
    override func viewDidLoad() {
        super.viewDidLoad()
        self.configView()
        self.registerCell()
        self.loadData()
    }
    func configView(){
        header.lbTitle.text = "card.menu.level".localized()
        header.selectBack = {
            self.backViewController()
        }
        header.btnRigth.isHidden = false
        header.selectBtnRight = {
            for controller in self.navigationController!.viewControllers as Array {
                if controller.isKind(of: SNGCardLevelVC.self) {
                    let view = controller as! SNGCardLevelVC
                    view.isClear = true
                    self.navigationController!.popToViewController(view, animated: true)
                    break
                }
            }
        }
    }
    
    func loadData(){
        
        self.viewModelSoftOTP.completionSuccess = { [weak self] message in
            guard let `self` = self else { return }
            DispatchQueue.main.async { [weak self] in
                guard let `self` = self else {return}
                if message == "GET_CHALLENGECODE_SUCCESS" {
                    if self.viewModelSoftOTP._challengeCode != nil {
                        let cardData = SNGTransactionCardModel()
                        cardData.cardNumber = self.cardItem!.cardNumber!
                        cardData.tokenCard = self.cardItem!.tokenCard!
                        cardData.transactionType = "CHANGE_LIMIT"
                        cardData.atmLimitNew = self.newAtmLimit!.replacingOccurrences(of: ",", with: "")
                        cardData.ecomLimitNew = self.newOnlineLimit!.replacingOccurrences(of: ",", with: "")
//                        cardData.d
                        cardData.otpTransactionId = self.viewModelSoftOTP._challengeCode!.transactionId
                        if self.viewModelSoftOTP._challengeCode!.approvalMethod == "SOFTOTP" {
                            if Global.isSoftOTPDevice {
                                let storyboard = UIStoryboard(name: "SNGConfirmPINSoftOTP", bundle: nil)
                                let viewController = storyboard.instantiateViewController(withIdentifier: "SNGConfirmPINSoftOTP") as! SNGConfirmPINSoftOTPVC
                                viewController.chalengCode = self.viewModelSoftOTP._challengeCode!.challenge
                                viewController.transactionId = self.viewModelSoftOTP._challengeCode!.transactionId
                                viewController.typeTransaction = .CARD
                                viewController.cardData = cardData
                                self.navigationController?.pushViewController(viewController, animated: true)
                            } else {
                                let agreeAction = Action(with: "Global.Agree".localized(), style: .normalRed) {[weak self] in
                                    guard self != nil else {return}
                                }
                                self.showPopupTemplate(title: "settings.softotp.notsetup.title".localized(), content: "settings.softotp.notsetup.des".localized() , actions: [agreeAction], axis: .vertical)
                            }
                        } else {
                            let storyboard = UIStoryboard(name: "SNGConfirmOTPFromSMS", bundle: nil)
                            let viewController = storyboard.instantiateViewController(withIdentifier: "SNGConfirmOTPFromSMS") as! SNGConfirmOTPFromSMSVC
                            viewController.typeTransaction = .CARD
                            viewController.transactionId = self.viewModelSoftOTP._challengeCode!.transactionId
                            viewController.transactionData = cardData
                            self.navigationController?.pushViewController(viewController, animated: true)
                        }
                    }
                }
            }
        }
        self.viewModelSoftOTP.completionFailed = { [weak self] message in
            guard let `self` = self else { return }
            DispatchQueue.main.async {
                self.showError(error: message)
            }
        }
        
    }
    func loadColView(_ val: SNGCardModel){
        self.data = []
        self.data.append(SNGComboboxModel(id: "card.detail.type", text: " \(val.cardNumber!.inserting())"))
        self.data.append(SNGComboboxModel(id: "card.detail.accountNo", text: " \(val.accountNo!.inserting())"))
        self.data.append(SNGComboboxModel(id: "card.detail.product.des", text: " \(val.cardProductDesc!)"))
        self.data.append(SNGComboboxModel(id: "card.detail.ebosingname", text: " \(val.embosingName!)"))
        if self.cardItem!.type == "master" {
            self.data.append(SNGComboboxModel(id: "card.detail.owner", text: "card.detail.owner.main".localized()))
        } else {
            self.data.append(SNGComboboxModel(id: "card.detail.owner", text: "card.detail.owner.other".localized()))
        }
        self.data.append(SNGComboboxModel(id: "card.detail.atm.limitnow", text: " \(val.cardATMLimit!.atmLimit!.toCurrencyString("VND")) VND"))
        self.data.append(SNGComboboxModel(id: "card.detail.atm.limitnew", text: " \(self.newAtmLimit!.toCurrencyString("VND")) VND"))
        self.data.append(SNGComboboxModel(id: "card.detail.online.limitnow", text: "  \(val.cardECOMLimit!.ecomLimit!.toCurrencyString("VND")) VND"))
        self.data.append(SNGComboboxModel(id: "card.detail.online.limitnew", text: " \(self.newOnlineLimit!.toCurrencyString("VND")) VND"))
        let formatter = DateFormatter()
            formatter.dateFormat = "dd/MM/yyyy"
        self.data.append(SNGComboboxModel(id: "card.detail.dateNow", text: formatter.string(from: Date())))
        self.data.append(SNGComboboxModel(id: "card.detail.dateEnd", text: self.endDate))
        colView.reloadData()
    }
    func registerCell() {
        colView.register(UINib(nibName: SNGCollectionViewCellDetail.className, bundle: nil),
                         forCellWithReuseIdentifier: SNGCollectionViewCellDetail.className)
    }
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
            stackView.isHidden = false
            colViewConstrainBottom.constant = 88
        if self.cardItem != nil {
            self.loadColView(self.cardItem!)
        }
    }
    
    
    @IBAction func onConfirmTouch(_ sender: Any) {
        if let cardItem = self.cardItem {
            self.viewModelSoftOTP.getChallengeCode(transType: "CARD", accountNo: "", cardNo: cardItem.tokenCard!)
        }
    }
    
    @IBAction func onSelectEdit(_ sender: Any) {
        self.backViewController()
    }
    
    
}
extension SNGCardLevelDetailVC: UICollectionViewDelegate {
    
}

extension SNGCardLevelDetailVC: UICollectionViewDataSource {
    
    func collectionView(_ collectionView: UICollectionView, numberOfItemsInSection section: Int) -> Int {
        return self.data.count
    }
    
    func collectionView(_ collectionView: UICollectionView, cellForItemAt indexPath: IndexPath) -> UICollectionViewCell {
        // Collection Overdraft Account
        let cell = collectionView.dequeueReusableCell(withReuseIdentifier: SNGCollectionViewCellDetail.className, for: indexPath) as! SNGCollectionViewCellDetail
        cell.key.text = data[indexPath.row].id.localized()
        cell.hideDrowDown()
        cell.value.text = data[indexPath.row].text
        return cell
    }
}

// set style
extension SNGCardLevelDetailVC: UICollectionViewDelegateFlowLayout {
    func collectionView(_ collectionView: UICollectionView,
                        layout collectionViewLayout: UICollectionViewLayout,
                        sizeForItemAt indexPath: IndexPath) -> CGSize {
        return CGSize(width: self.view.frame.width , height: 56.5)
    }
    
    func collectionView(_ collectionView: UICollectionView,
                        layout collectionViewLayout: UICollectionViewLayout,
                        minimumLineSpacingForSectionAt section: Int) -> CGFloat {
        return 0
    }
}

